@@ -14,9 +14,10 @@ from SeasObjects.model.Coordinates import Coordinates
 from SeasObjects.model.Condition import Condition
 from SeasObjects.model.Entity import Entity
 from SeasObjects.model.Input import Input
+from SeasObjects.model.Obj import Obj
 from SeasObjects.model.Output import Output
 from SeasObjects.model.ValueObject import ValueObject
-from SeasObjects.model.Variant import Variant
+from SeasObjects.rdf.Variant import Variant
 from SeasObjects.model.Ring import Ring
 from SeasObjects.model.Response import Response
 from SeasObjects.factory.RequestFactory import RequestFactory
@@ -28,7 +29,7 @@ from SeasObjects.common.RESOURCE import RESOURCE
 from SeasObjects.common.PROPERTY import PROPERTY
 
 content_type = "text/turtle"
-seas_register_search_uri = "http://seas.asema.com/webapps/rs/search"
+seas_register_search_uri = "http://seas.asema.com/webapps/rs/v1.0e1.0/search"
 caller_seas_uri = ""
 serialization = SERIALIZATION.TURTLE
 debug = False
@@ -52,12 +53,14 @@ class RegistrySearchAgent(Agent):
             if debug:
                 print "Request to SEAS Search Service:"
                 print payload
+
             resp_str = self.runQuery(seas_register_search_uri, content_type, content_type, payload)
+            
             response = Response().fromString(resp_str, serialization)
             if response != None:
                 if debug:
                     print "Response from SEAS Search Service:"
-                    print Tools().toString(response, serialization)
+                    print resp_str
                 return response.getEntities()
             else:
                 if debug:
@@ -80,20 +83,18 @@ class RegistrySearchAgent(Agent):
     def generateSearchMessage(self):
         global entity
         request = RequestFactory().create(caller_seas_uri)
-        request.setMethod(RESOURCE.SEAS_READ)
+        request.setMethod(RESOURCE.READ)
         request.addEntity(entity)
         return Tools().toString(request, serialization)
         
     def setServiceUri(self, serviceUri):
         seas_register_search_uri = serviceUri
         
-    def ofName(self, searchString):
-        self.ofName(searchString, False)
         
     def ofDescription(self, searchString):
         condition = Condition()
         condition.addRegex("(?i)" + searchString)
-        entity.add(URIRef(PROPERTY.RDFS_COMMENT), condition)
+        entity.add(URIRef(PROPERTY.COMMENT), condition)
         
     def anyOfNames(self, searchStrings):
         global entity
@@ -103,7 +104,7 @@ class RegistrySearchAgent(Agent):
                 condition.addRegex("(?i)" + s)
             entity.add(URIRef(PROPERTY.RDFS_LABEL), condition)
             
-    def ofName(self, searchString, exactMatch):
+    def ofName(self, searchString, exactMatch=False):
         global entity
         if exactMatch:
             entity.setName(searchString)
@@ -112,6 +113,12 @@ class RegistrySearchAgent(Agent):
             condition.addRegex("(?i)" + searchString)
             entity.add(URIRef(PROPERTY.RDFS_LABEL), condition)
             
+    def ofPartialId(self, searchString):
+        global entity
+        condition = Condition()
+        condition.addRegex("(?i)" + searchString)
+        entity.add(URIRef(PROPERTY.ID), condition)
+            
     def ofType(self, type):
         global entity
         entity.addType(type)
@@ -160,26 +167,26 @@ class RegistrySearchAgent(Agent):
                 
     def polygonSearchArea(self, polygon):
         global entity
-        entity.add(URIRef(RESOURCE.SEAS_POLYGON), polygon)
+        entity.add(URIRef(RESOURCE.POLYGON), polygon)
         
     def multipolygonSearchArea(self, polygons):
         global entity
         for polygon in polygons:
-            entity.add(URIRef(RESOURCE.SEAS_POLYGON), polygon)
+            entity.add(URIRef(RESOURCE.POLYGON), polygon)
         
     def rectangeSearchArea(self, minCoords, maxCoords):
         global entity
-        entity.add(URIRef(PROPERTY.SEAS_MINLOCATION), minCoords)
-        entity.add(URIRef(PROPERTY.SEAS_MAXLOCATION), maxCoords)
+        entity.add(URIRef(PROPERTY.MINLOCATION), minCoords)
+        entity.add(URIRef(PROPERTY.MAXLOCATION), maxCoords)
         
     def pointSearchArea(self, center, kilometers):
         global entity
         ring = Ring()
-        ring.add(URIRef(PROPERTY.GEO_LAT), center.getLatitude())
-        ring.add(URIRef(PROPERTY.GEO_LONG), center.getLongitude())
+        ring.add(URIRef(PROPERTY.LAT), center.getLatitude())
+        ring.add(URIRef(PROPERTY.LONG), center.getLongitude())
         maxR = ValueObject()
-        maxR.setQuantity(RESOURCE.SEAS_DISTANCE)
-        maxR.setUnit(RESOURCE.SEAS_KILOMETER)
+        maxR.setQuantity(RESOURCE.LENGTH)
+        maxR.setUnit(RESOURCE.KILOMETER)
         maxR.setValue(Variant(kilometers))
         ring.setMaxRadius(maxR)
         entity.add(URIRef(NS.SEAS + "ring"), ring)
@@ -211,7 +218,7 @@ class RegistrySearchAgent(Agent):
         agent = RegistrySearchAgent()
         agent.clear()
         agent.setSenderUri(mySeasUri)
-        agent.ofType(RESOURCE.SEAS_SERVICE)
+        agent.ofType(RESOURCE.SERVICE)
         agent.ofOutputType(type)
         return agent.search()
 
@@ -219,11 +226,11 @@ class RegistrySearchAgent(Agent):
         agent = RegistrySearchAgent()
         agent.clear()
         agent.setSenderUri(mySeasUri)
-        agent.ofType(RESOURCE.SEAS_SERVICE)
+        agent.ofType(RESOURCE.SERVICE)
         agent.ofInputType(type)
         return agent.search()
 
-    def searchByDescription(self, mySeasUri, searchString, types = [RESOURCE.SEAS_ENTITY]):
+    def searchByDescription(self, mySeasUri, searchString, types = [RESOURCE.ENTITY]):
         agent = RegistrySearchAgent()
         agent.clear()
         agent.setSenderUri(mySeasUri)
@@ -231,6 +238,13 @@ class RegistrySearchAgent(Agent):
         agent.ofDescription(searchString)
         return agent.search()
 
+    def searchByPartialSeasId(self, mySeasUri, searchString):
+        agent = RegistrySearchAgent()
+        agent.clear()
+        agent.setSenderUri(mySeasUri)
+        agent.ofPartialId(searchString)
+        return agent.search()
+        
     def fetchBySeasId(self, mySeasUri, idToFetch):
         agent = RegistrySearchAgent()
         agent.clear()
@@ -282,7 +296,7 @@ class RegistrySearchAgent(Agent):
         e = Entity()
 
         # The types we want to search
-        e.setType(RESOURCE.SEAS_SERVICE)
+        e.setType(RESOURCE.SERVICE)
 
         activity = Activity()
         
