@@ -2,9 +2,12 @@ import datetime
 from SeasObjects.model.Request import Request
 from SeasObjects.model.Activity import Activity
 from SeasObjects.seasexceptions.InsufficientDataException import InsufficientDataException
-
+from SeasObjects.common.Tools import Tools
 from SeasObjects.common.RESOURCE import RESOURCE
+from SeasObjects.model.SystemOfInterest import SystemOfInterest
+from SeasObjects.model.Evaluation import Evaluation
 
+import traceback
 
 class RequestFactory(object):
 	
@@ -23,14 +26,14 @@ class RequestFactory(object):
 		# timestamp of when this message is being generated (now)
 		evaluation.setGeneratedAt(datetime.datetime.now())
 
-		evaluation.addType(RESOURCE.SEAS_REQUEST)
+		evaluation.addType(RESOURCE.REQUEST)
 		
 		return evaluation;
 
 	
 	def fromString(self, data, serialization):
 		try:
-			return Request().parse(Tools().getResourceByType(RESOURCE.SEAS_REQUEST, Tools().fromString(data, serialization)))
+			return Request().parse(Tools().getResourceByType(RESOURCE.REQUEST, Tools().fromString(data, serialization)))
 		except:
 			print "Unable to parse Evaluation by type seas:Request from the given string."
 			traceback.print_exc()
@@ -46,7 +49,7 @@ class RequestFactory(object):
 		# timestamp of when this message is being generated (now)
 		req.setGeneratedAt(datetime.datetime.now())
 
-		req.addType(RESOURCE.SEAS_REQUEST)
+		req.addType(RESOURCE.REQUEST)
 		
 		return req
 	
@@ -61,10 +64,10 @@ class RequestFactory(object):
 		# timestamp of when this message is being generated (now)
 		evaluation.setGeneratedAt(datetime.datetime.now());
 
-		evaluation.addType(RESOURCE.SEAS_EVALUATION)
-		evaluation.addCategory(RESOURCE.SEAS_FORECAST)
+		evaluation.addType(RESOURCE.EVALUATION)
+		evaluation.addCategory(RESOURCE.FORECAST)
 		systemOfInterest = SystemOfInterest()
-		systemOfInterest.setType(RESOURCE.SEAS_WEATHER)
+		systemOfInterest.setType(RESOURCE.WEATHER)
 		evaluation.setSystemOfInterest(systemOfInterest)
 		
 		return evaluation
