@@ -1,6 +1,10 @@
 from SeasObjects.common.PROPERTY import PROPERTY
+from SeasObjects.common.RESOURCE import RESOURCE
 from Evaluation import Evaluation
 from SeasObjects.rdf.Resource import Resource
+from SeasObjects.model.Condition import Condition
+
+import traceback
 
 class Ability(Evaluation):
 
@@ -8,7 +12,7 @@ class Ability(Evaluation):
 		Evaluation.__init__(self, uri)
 		self.isControlledBy = None
 		self.condition = None
-		self.setType(RESOURCE.SEAS_ABILITY)
+		self.setType(RESOURCE.ABILITY)
 	
 	def serialize(self, model):
 		resource = super(Ability, self).serialize(model)
@@ -16,11 +20,11 @@ class Ability(Evaluation):
 		# isControlledBy
 		if self.hasIsControlledBy():
 			controlledBy = model.createResource(self.isControlledBy)
-			resource.addProperty(model.createProperty( PROPERTY.SEAS_ISCONTROLLEDBY ), controlledBy)
+			resource.addProperty(model.createProperty( PROPERTY.ISCONTROLLEDBY ), controlledBy)
 
 		# condition
 		if self.hasCondition():
-			resource.addProperty(model.createProperty( PROPERTY.SEAS_HASCONDITION ), self.condition.serialize(model))
+			resource.addProperty(model.createProperty( PROPERTY.HASCONDITION ), self.condition.serialize(model))
 
 		return resource
 	
@@ -44,7 +48,7 @@ class Ability(Evaluation):
 			predicate = str(statement.getPredicate())
 	
 			# isControlledBy
-			if predicate == PROPERTY.SEAS_ISCONTROLLEDBY:
+			if predicate == PROPERTY.ISCONTROLLEDBY:
 				try:
 					self.setIsControlledBy(statement.getResource().toString())
 				except:
@@ -53,9 +57,9 @@ class Ability(Evaluation):
 				return
 	
 			# condition
-			if predicate == PROPERTY.SEAS_HASCONDITION:
+			if predicate == PROPERTY.HASCONDITION:
 				try:
-					self.setCondition(Condition.parse(statement.getResource()))
+					self.setCondition(Condition().parse(statement.getResource()))
 				except:
 					print "Unable to interpret seas:hasCondition value as resource."
 					traceback.print_exc()
