@@ -12,7 +12,7 @@ class Activity(Obj):
 
 	def __init__(self, uri = None):
 		Obj.__init__(self, uri)
-		self.setType(RESOURCE.SEAS_ACTIVITY)
+		self.setType(RESOURCE.ACTIVITY)
 		self.inputs = []
 		self.outputs = []
 		self.availabilities = []
@@ -24,27 +24,27 @@ class Activity(Obj):
 		# inputs
 		for input in self.inputs:
 			if input.getInputType() == Input.TYPE_DATA:
-				activity.addProperty(model.createProperty( PROPERTY.SEAS_HASINPUT ), input.serialize(model))
+				activity.addProperty(model.createProperty( PROPERTY.HASINPUT ), input.serialize(model))
 			if input.getInputType() == Input.TYPE_REFERENCE:
-				activity.addProperty(model.createProperty( PROPERTY.SEAS_HASREFINPUT ), input.serialize(model))	
+				activity.addProperty(model.createProperty( PROPERTY.HASREFINPUT ), input.serialize(model))	
 
 		# outputs
 		for output in self.outputs:
-			activity.addProperty(model.createProperty( PROPERTY.SEAS_HASOUTPUT ), output.serialize(model))
+			activity.addProperty(model.createProperty( PROPERTY.HASOUTPUT ), output.serialize(model))
 	
 		# availability
-		availabilityProp = model.createProperty( PROPERTY.SEAS_HASAVAILABILITY )
+		availabilityProp = model.createProperty( PROPERTY.HASAVAILABILITY )
 		for availability in self.availabilities:
 			activity.addProperty( availabilityProp, availability.serialize(model) )
 
 		# data availability
-		dataAvailabilityProp = model.createProperty( PROPERTY.SEAS_HASDATAAVAILABILITY )
+		dataAvailabilityProp = model.createProperty( PROPERTY.HASDATAAVAILABILITY )
 		for availability in self.dataAvailabilities:
 			activity.addProperty( dataAvailabilityProp, availability.serialize(model) )
 
 		# set interfaces
 		for iAddrs in self.interfaces:
-			activity.addProperty(model.createProperty( PROPERTY.SEAS_INTERFACE ), iAddrs.serialize(model))
+			activity.addProperty(model.createProperty( PROPERTY.INTERFACE ), iAddrs.serialize(model))
 
 		return activity
 	
@@ -73,7 +73,7 @@ class Activity(Obj):
 			predicate = str(statement.getPredicate())
 
 			# input data
-			if predicate == PROPERTY.SEAS_HASINPUT:
+			if predicate == PROPERTY.HASINPUT:
 				try:
 					self.addInput(Input().parse(statement.getResource()));
 				except:
@@ -82,7 +82,7 @@ class Activity(Obj):
 				return
 
 			# input reference
-			if predicate == PROPERTY.SEAS_HASREFINPUT:
+			if predicate == PROPERTY.HASREFINPUT:
 				try:
 					input = Input().parse(statement.getResource())
 					input.setInputType(Input.TYPE_REFERENCE)
@@ -93,7 +93,7 @@ class Activity(Obj):
 				return
 
 			# output
-			if  predicate == PROPERTY.SEAS_HASOUTPUT:
+			if  predicate == PROPERTY.HASOUTPUT:
 				try:
 					self.addOutput(Output().parse(statement.getResource()));
 				except:
@@ -102,7 +102,7 @@ class Activity(Obj):
 				return
 
 			# availability
-			if predicate == PROPERTY.SEAS_HASAVAILABILITY:
+			if predicate == PROPERTY.HASAVAILABILITY:
 				try:
 					self.addAvailability(Availability().parse(statement.getResource()))
 				except:
@@ -111,7 +111,7 @@ class Activity(Obj):
 				return
 
 			# data availability
-			if predicate == PROPERTY.SEAS_HASDATAAVAILABILITY:
+			if predicate == PROPERTY.HASDATAAVAILABILITY:
 				try:
 					self.addDataAvailability(Availability().parse(statement.getResource()))
 				except:
@@ -120,7 +120,7 @@ class Activity(Obj):
 				return
 
 			# interfaceaddress
-			if predicate == PROPERTY.SEAS_INTERFACE:
+			if predicate == PROPERTY.INTERFACE:
 				try:
 					self.addInterface(InterfaceAddress().parse(statement.getResource()))
 				except:
@@ -182,3 +182,16 @@ class Activity(Obj):
 
 	def addInterface(self, interfaceAddress):
 		self.interfaces.append(interfaceAddress)
+
+	def firstInput(self):
+		try:
+			return self.inputs[0]
+		except:
+			return None
+    
+	def firstOutput(self):
+		try:
+			return self.outputs[0]
+		except:
+			return None
+		
