@@ -1,12 +1,13 @@
 from SeasObjects.model.Ability import Ability
+from SeasObjects.common.RESOURCE import RESOURCE
 
 class Controllability(Ability):
 
 	def __init__(self, uri = None):
 		Ability.__init__(self, uri)
-		self.setType(RESOURCE.SEAS_CONTROLLABILITY)
+		self.setType(RESOURCE.CONTROLLABILITY)
 
-	def parse(resource):
+	def parse(self, resource):
 		if not resource.isAnon():
 			controllability = Controllability(resource.toString())
 		else:
