@@ -15,7 +15,7 @@ class Coordinates(Obj):
 		self.latitude = latitude
 		self.longitude = longitude
 		self.altitude = altitude
-		self.setType(RESOURCE.SEAS_COORDINATES);
+		self.setType(RESOURCE.GEO_POINT);
 	
 	def hasLongitude(self):
 		return self.longitude is not None
@@ -44,17 +44,24 @@ class Coordinates(Obj):
 	def getAltitude(self):
 		return self.altitude
 	
+	def toNude(self):
+		return ( self.latitude, self.longitude )
+	
+	def fromNude(self, value):
+		self.latitude = value[0]
+		self.longitude = value[1]
+	
 	def serialize(self, model):
 		coordinates = super(Coordinates, self).serialize(model)
 		
 		if self.hasLatitude():
-			coordinates.addProperty(model.createProperty( PROPERTY.GEO_LAT ), model.createTypedLiteral(self.getLatitude(), XSD.double))
+			coordinates.addProperty(model.createProperty( PROPERTY.LAT ), model.createTypedLiteral(self.getLatitude(), XSD.double))
 
 		if self.hasLongitude():
-			coordinates.addProperty(model.createProperty( PROPERTY.GEO_LONG ), model.createTypedLiteral(self.getLongitude(), XSD.double))
+			coordinates.addProperty(model.createProperty( PROPERTY.LONG ), model.createTypedLiteral(self.getLongitude(), XSD.double))
 
 		if self.hasAltitude():
-			coordinates.addProperty(model.createProperty( PROPERTY.GEO_ALT ), model.createTypedLiteral(self.getAltitude(), XSD.double))
+			coordinates.addProperty(model.createProperty( PROPERTY.ALT ), model.createTypedLiteral(self.getAltitude(), XSD.double))
 
 		return coordinates
 	
@@ -77,7 +84,7 @@ class Coordinates(Obj):
 			predicate = str(statement.getPredicate())
 			
 			# latitude
-			if predicate == PROPERTY.GEO_LAT:
+			if predicate == PROPERTY.LAT:
 				try:
 					self.setLatitude(statement.getDouble())
 				except:
@@ -86,7 +93,7 @@ class Coordinates(Obj):
 				return
 	
 			# longitude
-			if predicate == PROPERTY.GEO_LONG:
+			if predicate == PROPERTY.LONG:
 				try:
 					self.setLongitude(statement.getDouble());
 				except:
@@ -95,7 +102,7 @@ class Coordinates(Obj):
 				return
 			
 			# altitude
-			if predicate == PROPERTY.GEO_ALT:
+			if predicate == PROPERTY.ALT:
 				try:
 					self.setAltitude(statement.getDouble());
 				except:
@@ -105,4 +112,4 @@ class Coordinates(Obj):
 	
 			# pass on to Object
 			super(Coordinates, self).parse(statement)
-	
\ No newline at end of file
+	
