@@ -7,11 +7,10 @@ import traceback
 
 class Device(PhysicalEntity):
 
-	def __init__(self, country_code, uri = None):
+	def __init__(self, uri = None):
 		PhysicalEntity.__init__(self, uri)
-		self.country_code = country_code
 		self.managingSystemUri = None
-		self.setType(RESOURCE.SEAS_DEVICE);
+		self.setType(RESOURCE.DEVICE);
 	
 	def hasManagingSystemUri(self):
 		return self.managingSystemUri is not None
@@ -28,7 +27,7 @@ class Device(PhysicalEntity):
 		# set system uri
 		if self.hasManagingSystemUri():
 			system = model.createResource( self.managingSystemUri )
-			device.addProperty(model.createProperty( PROPERTY.SEAS_ISMANAGEDBY ), system)
+			device.addProperty(model.createProperty( PROPERTY.ISMANAGEDBY ), system)
 
 		return device
 
@@ -42,22 +41,23 @@ class Device(PhysicalEntity):
 	
 			for statement in resource.findProperties():
 				device.parse(statement)
-				
-				return device
+			
+			return device
 			
 		else:
 			# get predicate
-			
+			statement = resource
 			predicate = str(statement.getPredicate())
 
 			# ismanagedby
-			if predicate == PROPERTY.SEAS_ISMANAGEDBY:
+			if predicate == PROPERTY.ISMANAGEDBY:
 				try:
-					device.setManagingSystemUri(statement.getString())
+					self.setManagingSystemUri(statement.getString())
 				except:
 					print "Unable to interpret seas:isManagedBy value as resource."
 					traceback.print_exc()
-
+				return 
+			
 			# pass on to Object
-			super(Device, device).parse(statement)
+			super(Device, self).parse(statement)
 
