@@ -9,7 +9,7 @@ class Error(Obj):
 		Obj.__init__(self, uri)
 		self.message = None
 		self.code = 0
-		self.setType(RESOURCE.SEAS_ERROR);
+		self.setType(RESOURCE.ERROR);
 	
 	def setErrorMessage(self, em):
 		self.message = em
@@ -33,10 +33,10 @@ class Error(Obj):
 		error = super(Error, self).serialize(model)
 		
 		if self.hasErrorMessage():
-			error.addProperty(model.createProperty( PROPERTY.SEAS_ERRORMESSAGE ), model.createLiteral(self.getErrorMessage()))
+			error.addProperty(model.createProperty( PROPERTY.ERRORMESSAGE ), model.createLiteral(self.getErrorMessage()))
 		
 		if self.hasErrorCode():
-			error.addProperty(model.createProperty( PROPERTY.SEAS_ERRORCODE ), model.createLiteral(self.getErrorCode()))
+			error.addProperty(model.createProperty( PROPERTY.ERRORCODE ), model.createLiteral(self.getErrorCode()))
 		
 		return error
 	
@@ -52,12 +52,12 @@ class Error(Obj):
 			predicate = str(statement.getPredicate())
 
 			# managedby
-			if predicate == PROPERTY.SEAS_ERRORMESSAGE:
+			if predicate == PROPERTY.ERRORMESSAGE:
 				e.message = statement.getResource().toString()
 				continue
 
 			# interfaceaddress
-			if predicate == PROPERTY.SEAS_ERRORCODE:
+			if predicate == PROPERTY.ERRORCODE:
 				e.code = int(statement.getResource().toString())
 				continue
 
