@@ -4,7 +4,7 @@ from SeasObjects.model.Obj import Obj
 from SeasObjects.rdf.types import *
 
 from rdflib import XSD
-
+import traceback
 
 class InterfaceAddress(Obj):
 
@@ -15,30 +15,30 @@ class InterfaceAddress(Obj):
 		self.path = None
 		self.scheme = None
 		self.contentTypes = []
-		self.setType(RESOURCE.SEAS_INTERFACEADDRESS);
+		self.setType(RESOURCE.INTERFACEADDRESS);
 	
 	def serialize(self, model):
 		interfaceAddress = super(InterfaceAddress, self).serialize(model)
 		
 		# host
 		if self.hasHost():
-			interfaceAddress.addProperty(model.createProperty( PROPERTY.SEAS_HOST ), self.host)
+			interfaceAddress.addProperty(model.createProperty( PROPERTY.HOST ), self.host)
 
 		# port
 		if self.hasPort():
-			interfaceAddress.addProperty(model.createProperty( PROPERTY.SEAS_PORT ), model.createTypedLiteral(self.port, XSD.integer))
+			interfaceAddress.addProperty(model.createProperty( PROPERTY.PORT ), model.createTypedLiteral(self.port, XSD.integer))
 
 		# path
 		if self.hasPath():
-			interfaceAddress.addProperty(model.createProperty( PROPERTY.SEAS_PATH ), self.path)
+			interfaceAddress.addProperty(model.createProperty( PROPERTY.PATH ), self.path)
 
 		# scheme
 		if self.hasScheme():
-			interfaceAddress.addProperty(model.createProperty( PROPERTY.SEAS_SCHEME ), self.scheme)
+			interfaceAddress.addProperty(model.createProperty( PROPERTY.SCHEME ), self.scheme)
 
 		# content types
 		for cType in self.contentTypes:
-			interfaceAddress.addProperty(model.createProperty( PROPERTY.SEAS_CONTENTTYPE ), cType)
+			interfaceAddress.addProperty(model.createProperty( PROPERTY.CONTENTTYPE ), cType)
 
 		return interfaceAddress
 
@@ -55,7 +55,7 @@ class InterfaceAddress(Obj):
 			predicate = str(statement.getPredicate())
 
 			# scheme
-			if predicate == PROPERTY.SEAS_SCHEME:
+			if predicate == PROPERTY.SCHEME:
 				try :
 					interfaceAddress.scheme = statement.getString();
 				except:
@@ -64,7 +64,7 @@ class InterfaceAddress(Obj):
 				continue
 			
 			# host
-			if predicate == PROPERTY.SEAS_HOST:
+			if predicate == PROPERTY.HOST:
 				try :
 					interfaceAddress.host = statement.getString();
 				except:
@@ -73,7 +73,7 @@ class InterfaceAddress(Obj):
 				continue
 
 			# port
-			if predicate == PROPERTY.SEAS_PORT:
+			if predicate == PROPERTY.PORT:
 				try:
 					interfaceAddress.port = statement.getInt();
 				except:
@@ -82,7 +82,7 @@ class InterfaceAddress(Obj):
 				continue
 
 			# path
-			if predicate == PROPERTY.SEAS_PATH:
+			if predicate == PROPERTY.PATH:
 				try:
 					interfaceAddress.path = statement.getString()
 				except:
@@ -91,7 +91,7 @@ class InterfaceAddress(Obj):
 				continue
 
 			# content-type
-			if predicate == PROPERTY.SEAS_CONTENTTYPE:
+			if predicate == PROPERTY.CONTENTTYPE:
 				try:
 					interfaceAddress.addContentType(statement.getString())
 				except:
