@@ -22,29 +22,29 @@ class Message(Evaluation):
 		self.status = None
 		self.method = None
 		self.errors = []
-		self.setType(RESOURCE.SEAS_MESSAGE)
+		self.setType(RESOURCE.MESSAGE)
 		
 	def serialize(self, model):
 		resource = super(Message, self).serialize(model)
 
 		# errors
-		errorProp = model.createProperty( PROPERTY.SEAS_ERROR )
+		errorProp = model.createProperty( PROPERTY.ERROR )
 		for e in self.errors:
 			errorRes = e.serialize(model);
 			resource.addProperty( errorProp, errorRes )
 		
 		# status
 		if self.hasStatus():
-			resource.addProperty(model.createProperty( PROPERTY.SEAS_STATUS ), self.getStatus().serialize(model))
+			resource.addProperty(model.createProperty( PROPERTY.STATUS ), self.getStatus().serialize(model))
 
 		if self.hasMessageId():
-			resource.addProperty(model.createProperty( PROPERTY.SEAS_MESSAGEID ), model.createLiteral(self.getMessageId()))
+			resource.addProperty(model.createProperty( PROPERTY.ID ), model.createLiteral(self.getMessageId()))
 
 		if self.hasProcessId():
-			resource.addProperty(model.createProperty( PROPERTY.SEAS_PROCESSID ), model.createLiteral(self.getProcessId()))
+			resource.addProperty(model.createProperty( PROPERTY.PROCESSID ), model.createLiteral(self.getProcessId()))
 
 		if self.hasMethod():
-			resource.addProperty(model.createProperty( PROPERTY.SEAS_METHOD ), self.getMethod())
+			resource.addProperty(model.createProperty( PROPERTY.METHOD ), self.getMethod())
 
 		return resource
 	
@@ -53,7 +53,7 @@ class Message(Evaluation):
 		
 		if isinstance(resource, Resource):
 			if resource == None:
-				raise NullPointerException("Unable to parse null to Response.")
+				raise NonePointerException("Unable to parse null to Response.")
 	
 			if not resource.isAnon():
 				msg = Message(resource.toString())
@@ -73,7 +73,7 @@ class Message(Evaluation):
 			predicate = str(statement.getPredicate())
 
 			# status
-			if predicate == PROPERTY.SEAS_MESSAGEID:
+			if predicate == PROPERTY.ID:
 				try:
 					self.messageId = statement.getInt()
 				except:
@@ -82,7 +82,7 @@ class Message(Evaluation):
 				return
 
 			# status
-			if predicate == PROPERTY.SEAS_PROCESSID:
+			if predicate == PROPERTY.PROCESSID:
 				try:
 					self.processId = statement.getInt()
 				except:
@@ -91,7 +91,7 @@ class Message(Evaluation):
 				return
 			
 			# status
-			if predicate == PROPERTY.SEAS_STATUS:
+			if predicate == PROPERTY.STATUS:
 				try:
 					self.status = Status().parse(statement.getResource())
 				except:
@@ -100,7 +100,7 @@ class Message(Evaluation):
 				return
 			
 			# errors
-			if predicate == RESOURCE.SEAS_ERROR:
+			if predicate == RESOURCE.ERROR:
 				try:
 					self.addError(Error().parse(statement.getResource()))
 				except:
@@ -109,7 +109,7 @@ class Message(Evaluation):
 				return
 	
 			# status
-			if predicate == PROPERTY.SEAS_METHOD:
+			if predicate == PROPERTY.METHOD:
 				try:
 					self.method = URIRef(statement.toString())
 				except:
