@@ -6,19 +6,20 @@ from SeasObjects.model.Message import Message
 
 from SeasObjects.seasexceptions.NonePointerException import NonePointerException
 
+import traceback
 
 class Notification(Message):
 
 	def __init__(self, uri = None):
 		Message.__init__(self, uri)
-		self.setType(RESOURCE.SEAS_NOTIFICATION)
+		self.setType(RESOURCE.NOTIFICATION)
 			
 	def serialize(self, model):
 		return super(Notification, self).serialize(model)
 
 	def fromString(self, data, serialization):
 		try:
-			return Notification.parse(Tools().getResourceByType(RESOURCE.SEAS_NOTIFICATION, Tools().fromString(data, serialization)))
+			return Notification.parse(Tools().getResourceByType(RESOURCE.NOTIFICATION, Tools().fromString(data, serialization)))
 		except:
 			print "Unable to parse Notification from the given string."
 			traceback.print_exc()
