@@ -20,6 +20,7 @@ class Obj(object):
 		self.description = None
 		self.types = []
 		self.provenances = []
+		self.targets = []
 
 		# map for properties (name, propertyobject pairs)
 		self.properties = {}
@@ -42,7 +43,7 @@ class Obj(object):
 		# sameas
 		if self.hasSameAs():
 			sameAsRes = model.createResource(self.sameAs)
-			owlSameAs = model.createProperty( PROPERTY.OWL_SAMEAS )
+			owlSameAs = model.createProperty( PROPERTY.SAMEAS )
 			resource.addProperty( owlSameAs, sameAsRes )
 
 		# types
@@ -53,9 +54,13 @@ class Obj(object):
 			except:
 				serialized = URIRef(type)
 			resource.addProperty( typeProp, serialized )
-
+			
+		# targets
+		for target in self.targets:
+			resource.addProperty(model.createProperty( PROPERTY.TARGET ), model.createResource(target))
+		
 		# provenances
-		provenanceProp = model.createProperty( PROPERTY.SEAS_PROVENANCE )
+		provenanceProp = model.createProperty( PROPERTY.PROVENANCE )
 		for p in self.provenances:
 			resource.addProperty( provenanceProp, p.serialize(model) )
 
@@ -66,7 +71,7 @@ class Obj(object):
 
 		# comment
 		if self.hasDescription():
-			rdfsComment = model.createProperty( PROPERTY.RDFS_COMMENT )
+			rdfsComment = model.createProperty( PROPERTY.COMMENT )
 			resource.addProperty( rdfsComment, self.description )
 
 		# add object properties
@@ -84,7 +89,7 @@ class Obj(object):
 		
 		if not isinstance(property, URIRef):
 			obj = Parameter(key = property, value = entry)
-			property = PROPERTY.SEAS_PARAMETER
+			property = PROPERTY.PARAMETER
 		else:
 			obj = entry
 		resource.addProperty( model.createProperty( property ), self._convert(obj, model))
@@ -121,7 +126,7 @@ class Obj(object):
 				return
 	
 			# sameas
-			if predicate == PROPERTY.OWL_SAMEAS:
+			if predicate == PROPERTY.SAMEAS:
 				try:
 					self.setSameAs(statement.getResource().toString())
 				except:
@@ -130,7 +135,7 @@ class Obj(object):
 				return
 
 			# provenance
-			if predicate == PROPERTY.SEAS_PROVENANCE:
+			if predicate == PROPERTY.PROVENANCE:
 				try:
 					self.addProvenance(Provenance().parse(statement.getResource()))
 				except:
@@ -138,6 +143,15 @@ class Obj(object):
 					traceback.print_exc() 
 				return
 
+			# target
+			if predicate == PROPERTY.TARGET:
+				try:
+					self.addTarget(statement.getString())
+				except:
+					print"Unable to interpret seas:target value as literal string."
+					traceback.print_exc()
+				return
+			
 			# label
 			if predicate == PROPERTY.RDFS_LABEL:
 				try:
@@ -148,7 +162,7 @@ class Obj(object):
 				return
 	
 			# comment
-			if predicate == PROPERTY.RDFS_COMMENT:
+			if predicate == PROPERTY.COMMENT:
 				try:
 					self.setDescription(statement.getString())
 				except:
@@ -157,7 +171,7 @@ class Obj(object):
 				return
 	
 			# parameters
-			if predicate == PROPERTY.SEAS_PARAMETER:
+			if predicate == PROPERTY.PARAMETER:
 				p = Parameter().parse(statement.getResource())
 				self.add(p.getKey(), p.getValue())
 				return 
@@ -190,7 +204,12 @@ class Obj(object):
 					self.add(URIRef(predicate), Obj().parse(resource));
 				
 				return	
-				
+	
+	def toNude(self):
+		return self.toString()
+	
+	def fromNude(self):
+		pass
 
 	def getId(self):
 		return self.toString()
@@ -218,6 +237,19 @@ class Obj(object):
 	def getSameAs(self):
 		return self.sameAs
 	
+	def hasTarget(self):
+		return len(self.targets) > 0
+	
+	def firstTarget(self):
+		if self.hasTarget(): return self.targets[0]
+		return None
+	
+	def getTargets(self):
+		return self.targets
+	
+	def addTarget(self, t):
+		self.targets.append(t)
+		
 	def isOfType(self, type):
 		if not isinstance(type, URIRef):
 			type = URIRef(type)
@@ -272,7 +304,7 @@ class Obj(object):
 		return len(self.properties) > 0
 	
 	def getProperties(self):
-		from Variant import Variant
+		from SeasObjects.rdf.Variant import Variant
 		map = {}
 		
 		for key, value in self.properties.iteritems():
@@ -287,7 +319,7 @@ class Obj(object):
 		return map
 
 	def get(self, property):
-		from Variant import Variant
+		from SeasObjects.rdf.Variant import Variant
 		ret = []
 		
 		if self.properties.has_key(property):
@@ -298,7 +330,19 @@ class Obj(object):
 					ret.append(Variant(e))
 		
 		return ret
-
+	
+	def getFirst(self, property):
+		try:
+			return self.get(property)[0]
+		except:
+			return None
+		
+	def getFirstValue(self, property):
+		try:
+			return self.getFirst(property).getValue();
+		except:
+			return None
+		
 	def add(self, property, obj):
 		if not self.properties.has_key(property):
 			self.properties[property] = []
