@@ -11,7 +11,7 @@ class Organization(Entity):
 
 	def __init__(self, uri = None):
 		Entity.__init__(self, uri)
-		self.setType(RESOURCE.SEAS_ORGANIZATION)
+		self.setType(RESOURCE.ORGANIZATION)
 
 	def serialize(self, model):
 		organzization = super(Organization, self).serialize(model)
