@@ -2,12 +2,14 @@ from SeasObjects.common.RESOURCE import RESOURCE
 from SeasObjects.common.PROPERTY import PROPERTY
 from SeasObjects.common.Tools import Tools
 from SeasObjects.model.Obj import Obj
-from SeasObjects.model.Variant import Variant
+from SeasObjects.rdf.Variant import Variant
 
 from SeasObjects.rdf.Resource import Resource
-from SeasObjects.rdf.RdfList import RdfList
+from SeasObjects.rdf.Property import Property
+from SeasObjects.rdf.LinkedList import LinkedList
 from SeasObjects.rdf.types import *
 from rdflib import Literal
+from rdflib.namespace import RDF
 
 import traceback
 
@@ -15,7 +17,7 @@ class Parameter(Obj):
 
 	def __init__(self, key = None, value = None):
 		Obj.__init__(self)
-		self.setType(RESOURCE.SEAS_PARAMETER)
+		self.setType(RESOURCE.PARAMETER)
 		self.key = key
 		self.value = value
 		
@@ -41,15 +43,17 @@ class Parameter(Obj):
 		resource = super(Parameter, self).serialize(model)
 	
 		if self.hasKey():
-			resource.addProperty(model.createProperty( PROPERTY.SEAS_PARAMETER_KEY ), Literal(self.getKey()))
+			resource.addProperty(model.createProperty( PROPERTY.KEY ), Literal(self.getKey()))
 		
 		if self.hasValue():
 			if isinstance(self.getValue(), Obj) or isinstance(self.getValue(), Variant):
 				resource.addProperty(model.createProperty( PROPERTY.RDF_VALUE ), self.getValue().serialize(model))
 			elif isinstance(self.getValue(), list):
-				rdfList = model.createList()
+				rdfList = model.createOrderedList()
 				rdfList.add_items(self.getValue())
-				resource.addProperty(model.createProperty(PROPERTY.RDF_VALUE), rdfList)
+				listContainer = model.createResource()
+				listContainer.addProperty(Property(RDF.first), rdfList)
+				resource.addProperty(model.createProperty(PROPERTY.RDF_VALUE), listContainer)
 			else:
 				resource.addProperty(model.createProperty(PROPERTY.RDF_VALUE), Literal(self.getValue()))
 		return resource
@@ -74,7 +78,7 @@ class Parameter(Obj):
 			# get predicate
 			predicate = str(statement.getPredicate())
 			
-			if predicate == PROPERTY.SEAS_PARAMETER_KEY:
+			if predicate == PROPERTY.KEY:
 				
 				try:
 					self.setKey(statement.getString())
@@ -90,7 +94,7 @@ class Parameter(Obj):
 					try:
 						self.setValue(target_class().parse(statement.getResource()))
 					except:
-						print "Unable to interpret seas:value as value for Parameter."
+						print "Unable to interpret rdf:value as value for Parameter."
 						traceback.print_exc()
 					return
 				elif statement.getResource().model.is_list(statement.getObject()):
