@@ -16,7 +16,7 @@ class PhysicalEntity(Entity):
 		self.direction = None
 		self.size = None
 		self.weight = None
-		self.setType(RESOURCE.SEAS_PHYSICALENTITY)
+		self.setType(RESOURCE.PHYSICALENTITY)
 		
 	def hasVelocity(self):
 		return self.velocity is not None
@@ -69,23 +69,23 @@ class PhysicalEntity(Entity):
 	
 		# velocity
 		if self.hasVelocity():
-			resource.addProperty( model.createProperty( PROPERTY.SEAS_SPEED ), self.velocity.serialize(model) )
+			resource.addProperty( model.createProperty( PROPERTY.VELOCITY ), self.velocity.serialize(model) )
 	
 		# orientation
 		if self.hasOrientation():
-			resource.addProperty( model.createProperty( PROPERTY.SEAS_ORIENTATION ), self.orientation.serialize(model) )
+			resource.addProperty( model.createProperty( PROPERTY.ORIENTATION ), self.orientation.serialize(model) )
 	
 		# size
 		if self.hasSize():
-			resource.addProperty( model.createProperty( PROPERTY.SEAS_SIZE ), self.size.serialize(model) )
+			resource.addProperty( model.createProperty( PROPERTY.SIZE ), self.size.serialize(model) )
 	
 		# direction
 		if self.hasDirection():
-			resource.addProperty( model.createProperty( PROPERTY.SEAS_DIRECTION ), self.direction.serialize(model) )
+			resource.addProperty( model.createProperty( PROPERTY.DIRECTION ), self.direction.serialize(model) )
 	
 		# weight
 		if self.hasWeight():
-			resource.addProperty( model.createProperty( PROPERTY.SEAS_WEIGHT ), self.weight.serialize(model) )
+			resource.addProperty( model.createProperty( PROPERTY.WEIGHT ), self.weight.serialize(model) )
 
 		return resource
 	
@@ -98,7 +98,7 @@ class PhysicalEntity(Entity):
 		
 		if isinstance(resource, Resource):
 			if resource == None:
-				raise NullPointerException("Unable to parse null to PhysicalEntity.")
+				raise NonePointerException("Unable to parse null to PhysicalEntity.")
 	
 			if not resource.isAnon():
 				entity = PhysicalEntity(resource.toString())
@@ -118,7 +118,7 @@ class PhysicalEntity(Entity):
 			predicate = str(statement.getPredicate())
 
 			# status
-			if predicate == PROPERTY.SEAS_SPEED:
+			if predicate == PROPERTY.VELOCITY:
 				try:
 					self.setVelocity(Velocity().parse(statement.getResource()))
 				except:
@@ -127,7 +127,7 @@ class PhysicalEntity(Entity):
 				return
 
 			# status
-			if predicate == PROPERTY.SEAS_ORIENTATION:
+			if predicate == PROPERTY.ORIENTATION:
 				try:
 					self.setOrientation(Orientation().parse(statement.getResource()))
 				except:
@@ -136,7 +136,7 @@ class PhysicalEntity(Entity):
 				return
 			
 			# status
-			if predicate == PROPERTY.SEAS_SIZE:
+			if predicate == PROPERTY.SIZE:
 				try:
 					self.setSize(Size().parse(statement.getResource()))
 				except:
@@ -145,7 +145,7 @@ class PhysicalEntity(Entity):
 				return
 			
 			# errors
-			if predicate == PROPERTY.SEAS_DIRECTION:
+			if predicate == PROPERTY.DIRECTION:
 				try:
 					self.setDirection(Direction().parse(statement.getResource()))
 				except:
@@ -153,7 +153,7 @@ class PhysicalEntity(Entity):
 					traceback.print_exc() 
 				return
 			
-			if predicate == PROPERTY.SEAS_WEIGHT:
+			if predicate == PROPERTY.WEIGHT:
 				try:
 					self.setWeight(ValueObject().parse(statement.getResource()))
 				except:
@@ -162,4 +162,4 @@ class PhysicalEntity(Entity):
 				return
 	
 			# pass on to Evaluation
-			super(PhysicalEntity, self).parse(statement);
\ No newline at end of file
+			super(PhysicalEntity, self).parse(statement);
