@@ -8,6 +8,8 @@ from SeasObjects.rdf.Resource import Resource
 from SeasObjects.rdf.types import *
 from rdflib import XSD
 
+import traceback
+
 class Provenance(Obj):
 
 	def __init__(self, uri = None):
@@ -17,7 +19,7 @@ class Provenance(Obj):
 		self.generationMethods = []
 		self.dataSources = []
 		self.props =[]
-		self.setType(RESOURCE.SEAS_PROVENANCE)
+		self.setType(RESOURCE.PROVENANCE)
 		
 	def hasGeneratedBy(self):
 		return self.generatedBy is not None
@@ -65,10 +67,10 @@ class Provenance(Obj):
 			self.dataSources.append(Obj(dataSource))
 			
 	def setDataSources(self, _dataSources):
-		self.dataSources = dataSources
+		self.dataSources = _dataSources
 		
 	def hasProperty(self):
-		return len(props) > 0
+		return len(self.props) > 0
 	
 	def getProperties(self):
 		return self.props
@@ -84,19 +86,19 @@ class Provenance(Obj):
 	
 		# generatedby
 		if self.hasGeneratedBy():
-			resource.addProperty( model.createProperty( PROPERTY.SEAS_GENERATEDBY ), self.generatedBy.serialize(model) )
+			resource.addProperty( model.createProperty( PROPERTY.GENERATEDBY ), self.generatedBy.serialize(model) )
 
 		# generatedat
 		if self.hasGeneratedAt():
-			resource.addProperty(model.createProperty( PROPERTY.SEAS_GENERATEDAT ), model.createLiteral(self.getGeneratedAt()))
+			resource.addProperty(model.createProperty( PROPERTY.GENERATEDAT ), model.createLiteral(self.getGeneratedAt()))
 	
 		# generationMethods
 		for i in range(len(self.generationMethods)):
-			resource.addProperty(model.createProperty( PROPERTY.SEAS_GENERATIONMETHOD ), self.generationMethods[i].serialize(model))
+			resource.addProperty(model.createProperty( PROPERTY.GENERATIONMETHOD ), self.generationMethods[i].serialize(model))
 	
 		# dataSources
 		for i in range(len(self.dataSources)):
-			resource.addProperty(model.createProperty( PROPERTY.SEAS_DATASOURCE ), self.dataSources[i].serialize(model))
+			resource.addProperty(model.createProperty( PROPERTY.DATASOURCE ), self.dataSources[i].serialize(model))
 	
 		# props
 		for i in range(len(self.props)):
@@ -125,7 +127,7 @@ class Provenance(Obj):
 			predicate = str(statement.getPredicate())
 	
 			# generatedby
-			if predicate == PROPERTY.SEAS_GENERATEDBY:
+			if predicate == PROPERTY.GENERATEDBY:
 				try:
 					self.setGeneratedBy(Activity().parse(statement.getResource()))
 				except:
@@ -134,7 +136,7 @@ class Provenance(Obj):
 				return
 		
 			# generatedat
-			if predicate == PROPERTY.SEAS_GENERATEDAT:
+			if predicate == PROPERTY.GENERATEDAT:
 				try:
 					self.setGeneratedAt(statement.getObject().toPython())
 				except:
@@ -143,7 +145,7 @@ class Provenance(Obj):
 				return
 		
 			# generationMethod
-			if predicate == PROPERTY.SEAS_GENERATIONMETHOD:
+			if predicate == PROPERTY.GENERATIONMETHOD:
 				try:
 					self.addGenerationMethod(Obj().parse(statement.getResource()))
 				except:
@@ -152,7 +154,7 @@ class Provenance(Obj):
 				return
 		
 			# dataSource
-			if predicate == PROPERTY.SEAS_DATASOURCE:
+			if predicate == PROPERTY.DATASOURCE:
 				try:
 					self.addDataSource(Obj().parse(statement.getResource()))
 				except:
