@@ -1,5 +1,5 @@
 from SeasObjects.model.Obj import Obj
-from SeasObjects.model.Variant import Variant
+from SeasObjects.rdf.Variant import Variant
 from SeasObjects.model.TemporalContext import TemporalContext
 
 from SeasObjects.rdf.Resource import Resource
@@ -12,7 +12,7 @@ class Status(Obj):
 		
 	def __init__(self, uri = None):
 		Obj.__init__(self, uri)
-		self.setType(RESOURCE.SEAS_STATUS);
+		self.setType(RESOURCE.STATUS);
 		self.percentage = None
 		self.total = None
 		self.completed = None
@@ -23,19 +23,19 @@ class Status(Obj):
 		
 		# percentage
 		if self.hasPercentage():
-			resource.addProperty(model.createProperty(PROPERTY.SEAS_PERCENTAGE), self.percentage.serialize(model))
+			resource.addProperty(model.createProperty(PROPERTY.PERCENTAGE), self.percentage.serialize(model))
 
 		# total
 		if self.hasTotal():
-			resource.addProperty(model.createProperty(PROPERTY.SEAS_TOTAL), model.createTypedLiteral(self.total, XSD.int))
+			resource.addProperty(model.createProperty(PROPERTY.TOTAL), model.createTypedLiteral(self.total, XSD.int))
 	
 		# completed
 		if self.hasCompleted():
-			resource.addProperty(model.createProperty(PROPERTY.SEAS_COMPLETED), model.createTypedLiteral(self.completed, XSD.int))
+			resource.addProperty(model.createProperty(PROPERTY.COMPLETED), model.createTypedLiteral(self.completed, XSD.int))
 
 		# temporalcontext
 		if self.hasTemporalContext():
-			resource.addProperty(model.createProperty(PROPERTY.SEAS_TEMPORALCONTEXT), self.temporalContext.serialize(model))
+			resource.addProperty(model.createProperty(PROPERTY.TEMPORALCONTEXT), self.temporalContext.serialize(model))
 
 		return resource
 
@@ -57,22 +57,22 @@ class Status(Obj):
 			predicate = str(statement.getPredicate())
 	
 			# percentage
-			if predicate == PROPERTY.SEAS_PERCENTAGE:
+			if predicate == PROPERTY.PERCENTAGE:
 				self.setPercentage(Variant().parse(statement))
 				return
 
 			# total
-			if predicate == PROPERTY.SEAS_TOTAL:
+			if predicate == PROPERTY.TOTAL:
 				self.setTotal(statement.getInt())
 				return
 
 			# completed
-			if predicate == PROPERTY.SEAS_COMPLETED:
+			if predicate == PROPERTY.COMPLETED:
 				self.setCompleted(statement.getInt())
 				return
 
 			# temporalcontext
-			if predicate == PROPERTY.SEAS_TEMPORALCONTEXT:
+			if predicate == PROPERTY.TEMPORALCONTEXT:
 				self.setTemporalContext(TemporalContext().parse(statement.getResource()))
 				return
 
@@ -119,8 +119,8 @@ class Status(Obj):
 	def hasTemporalContext(self):
 		return self.temporalContext is not None
 
-	def getPercentageAsInteger():
+	def getPercentageAsInteger(self):
 		return int(self.percentage)
 
-	def getPercentageAsDouble():
-		return double(self.percentage)
+	def getPercentageAsDouble(self):
+		return float(self.percentage)
