@@ -13,17 +13,14 @@ class SystemOfInterest(Entity):
 		Entity.__init__(self, uri)
 		self.registerKey = None
 		self.realizedBy = None
-		self.setType(RESOURCE.SEAS_SYSTEM_OF_INTEREST)
+		self.setType(RESOURCE.SYSTEMOFINTEREST)
 	
 	def serialize(self, model):
 		systemOfInterest = super(SystemOfInterest, self).serialize(model)
 		
-		# registerkey
-		if self.hasRegisterKey():
-			systemOfInterest.addProperty(model.createProperty( PROPERTY.SEAS_REGISTERKEY ), self.registerKey)
-
+		
 		if self.isRealizedBy():
-			systemOfInterest.addProperty(model.createProperty( PROPERTY.SEAS_REALIZEDBY ), self.realizedBy.serialize(model) )
+			systemOfInterest.addProperty(model.createProperty( PROPERTY.REALIZEDBY ), self.realizedBy.serialize(model) )
 
 		return systemOfInterest
 
@@ -45,20 +42,10 @@ class SystemOfInterest(Entity):
 		else:
 			statement = resource
 			# get predicate
-			predicate = str(statement.getPredicate())
-				
-			# reg key
-			if predicate == PROPERTY.SEAS_REGISTERKEY:
-				try:
-					self.setRegisterKey(statement.getString())
-				except:
-					print "Unable to interpret seas:registerKey value as literal string."
-					print sys.exc_info()[1]
-					traceback.print_exc() 
-				return
+			predicate = str(statement.getPredicate())				
 			
 			# reg key
-			if predicate == PROPERTY.SEAS_REALIZEDBY:
+			if predicate == PROPERTY.REALIZEDBY:
 				try:
 					self.setRealizedBy(PhysicalEntity().parse(statement.getResource()))
 				except:
