@@ -1,5 +1,7 @@
 from SeasObjects.common.RESOURCE import RESOURCE
 from SeasObjects.common.PROPERTY import PROPERTY
+from SeasObjects.rdf.Resource import Resource
+from SeasObjects.rdf.Property import Property
 from SeasObjects.model.Obj import Obj
 from SeasObjects.model.Evaluation import Evaluation
 from SeasObjects.model.SystemOfInterest import SystemOfInterest
@@ -8,6 +10,7 @@ from SeasObjects.model.TemporalContext import TemporalContext
 import traceback
 
 from rdflib import XSD
+from rdflib.namespace import RDF
 
 
 class TimeSeries(Obj):
@@ -20,7 +23,7 @@ class TimeSeries(Obj):
 		self.list = []
 		self.systemOfInterest = None
 		self.temporalContext = None
-		self.setType(RESOURCE.SEAS_TIMESERIES)
+		self.setType(RESOURCE.TIMESERIES)
 
 	def serialize(self, model):
 		ts = super(TimeSeries, self).serialize(model);
@@ -28,103 +31,113 @@ class TimeSeries(Obj):
 		# quantity
 		if self.hasQuantity():
 			quantity = model.createResource(self.quantity)
-			ts.addProperty(model.createProperty( PROPERTY.SEAS_QUANTITY ), quantity)
+			ts.addProperty(model.createProperty( PROPERTY.QUANTITYKIND ), quantity)
 		
 		# unit
 		if self.hasUnit():
 			unit = model.createResource(self.unit)
-			ts.addProperty(model.createProperty( PROPERTY.SEAS_UNIT ), unit)
+			ts.addProperty(model.createProperty( PROPERTY.UNIT ), unit)
 
 		# timestep
 		if self.hasTimeStep():
-			ts.addProperty(model.createProperty( PROPERTY.SEAS_TIMESTEP ), model.createTypedLiteral(self.getTimeStep(), XSD.duration))
+			ts.addProperty(model.createProperty( PROPERTY.TIMESTEP ), model.createTypedLiteral(self.getTimeStep(), XSD.duration))
 	
 		# list
 		if self.hasList():
-			rdfList = model.createList()
+			rdfList = model.createOrderedList()
 			rdfList.add_items(self.list)
 			
-			ts.addProperty(model.createProperty( PROPERTY.SEAS_LIST ), rdfList)
+			listContainer = model.createResource()
+			listContainer.addProperty(Property(RDF.first), rdfList)
+			
+			ts.addProperty(model.createProperty( PROPERTY.LIST ), listContainer)
 
 		# systemOfInterest
 		if self.hasSystemOfInterest():
-			ts.addProperty(model.createProperty( PROPERTY.SEAS_SYSTEMOFINTEREST ), self.systemOfInterest.serialize(model))
+			ts.addProperty(model.createProperty( PROPERTY.SYSTEMOFINTEREST ), self.systemOfInterest.serialize(model))
 
 		# temporalcontext
 		if self.hasTemporalContext():
-			ts.addProperty(model.createProperty( PROPERTY.SEAS_TEMPORALCONTEXT ), self.temporalContext.serialize(model))
+			ts.addProperty(model.createProperty( PROPERTY.TEMPORALCONTEXT ), self.temporalContext.serialize(model))
 
 		return ts;
 
 	def parse(self, resource):
-		if not resource.isAnon():
-			timeSeries = TimeSeries(resource.toString())
+		if isinstance(resource, Resource):
+			if not resource.isAnon():
+				timeSeries = TimeSeries(resource.toString())
+			else:
+				timeSeries = TimeSeries()
+			timeSeries.clearTypes()
+			
+			for statement in resource.findProperties():
+				# parse statement
+				timeSeries.parse(statement);
+			
+			return timeSeries
 		else:
-			timeSeries = TimeSeries()
-		timeSeries.clearTypes()
-
-		for statement in resource.findProperties():
+			statement = resource
+			
 			# get predicate
 			predicate = str(statement.getPredicate())
 
 			# quantity
-			if predicate == PROPERTY.SEAS_QUANTITY:
+			if predicate == PROPERTY.QUANTITYKIND:
 				try:
-					timeSeries.setQuantity(statement.getResource().toString())
+					self.setQuantity(statement.getResource().toString())
 				except:
 					print "Unable to interpret seas:quantity value as resource."
 					traceback.print_exc() 
-				continue
-
+				return
+			
 			# unit
-			if predicate == PROPERTY.SEAS_UNIT:
+			if predicate == PROPERTY.UNIT:
 				try:
-					timeSeries.setUnit(statement.getResource().toString())
+					self.setUnit(statement.getResource().toString())
 				except:
 					print "Unable to interpret seas:unit value as resource."
 					traceback.print_exc() 
-				continue
-
+				return
+			
 			# timestep
-			if predicate == PROPERTY.SEAS_TIMESTEP:
+			if predicate == PROPERTY.TIMESTEP:
 				try:
-					timeSeries.setTimeStep(statement.getString());
+					self.setTimeStep(statement.getString());
 				except:
 					print "Unable to interpret seas:timeStep value as literal string."
 					traceback.print_exc() 
-				continue
-
+				return
+			
 			# list
-			if predicate == PROPERTY.SEAS_LIST:
+			if predicate == PROPERTY.LIST:
 				try:
-					timeSeries.setList(statement.getResource().toList(Evaluation))
+					self.setList(statement.getResource().toList(Evaluation))
 				except:
 					print "Unable to interpret seas:list value as resource."
 					traceback.print_exc() 
-				continue
-
+				return
+			
 			# systemofinterest
-			if predicate == PROPERTY.SEAS_SYSTEMOFINTEREST:
+			if predicate == PROPERTY.SYSTEMOFINTEREST:
 				try:
-					timeSeries.setSystemOfInterest(SystemOfInterest().parse(statement.getResource()))
+					self.setSystemOfInterest(SystemOfInterest().parse(statement.getResource()))
 				except:
 					print "Unable to interpret seas:systemOfInterest value as resource."
 					traceback.print_exc() 
-				continue
-
+				return
+			
 			# temporalcontext
-			if predicate == PROPERTY.SEAS_TEMPORALCONTEXT:
+			if predicate == PROPERTY.TEMPORALCONTEXT:
 				try:
-					timeSeries.setTemporalContext(TemporalContext().parse(statement.getResource()))
+					self.setTemporalContext(TemporalContext().parse(statement.getResource()))
 				except:
 					print "Unable to interpret seas:temporalContext value as resource."
 					traceback.print_exc() 
-				continue
-
+				return
+			
 			# pass on to Object
-			super(TimeSeries, timeSeries).parse(statement)
+			super(TimeSeries, self).parse(statement)
 		
-		return timeSeries
 
 
 	def hasQuantity(self):
@@ -169,7 +182,7 @@ class TimeSeries(Obj):
 	def hasSystemOfInterest(self):
 		return self.systemOfInterest is not None
 
-	def setSystemOfInterest(self):
+	def getSystemOfInterest(self):
 		return self.systemOfInterest
 
 	def setSystemOfInterest(self, system):
