@@ -1,7 +1,7 @@
 from SeasObjects.common.PROPERTY import PROPERTY
 from SeasObjects.common.RESOURCE import RESOURCE
 from SeasObjects.model.Obj import Obj
-from SeasObjects.model.Variant import Variant
+from SeasObjects.rdf.Variant import Variant
 
 from rdflib import URIRef
 import traceback
@@ -9,14 +9,17 @@ import traceback
 
 class ValueObject(Obj):
 
-	def __init__(self, uri = None, quantity = None, unit = None, value = None):
+	def __init__(self, uri = None, quantity = None, unit = None, value = None, maximum = None, minimum = None):
 		Obj.__init__(self, uri)
 		if quantity is not None and not isinstance(quantity, URIRef): quantity = URIRef(quantity)
 		if unit is not None and not isinstance(unit, URIRef): unit = URIRef(unit)
+		if value is not None and not isinstance(unit, Variant): value = Variant(value)
 		self.quantity = quantity
 		self.unit = unit
 		self.value = value
-		self.setType(RESOURCE.SEAS_VALUEOBJECT)
+		self.maximum = maximum
+		self.minimum = minimum
+		self.setType(RESOURCE.VALUEOBJECT)
 
 	def serialize(self, model):
 		valueObject = super(ValueObject, self).serialize(model)
@@ -24,58 +27,64 @@ class ValueObject(Obj):
 		# quantity
 		if self.hasQuantity():
 			quantity = model.createResource(self.quantity)
-			valueObject.addProperty(model.createProperty( PROPERTY.SEAS_QUANTITY ), self.quantity)
+			valueObject.addProperty(model.createProperty( PROPERTY.QUANTITYKIND ), self.quantity)
 		
 		# unit
 		if self.hasUnit():
 			unit = model.createResource(self.unit)
-			valueObject.addProperty(model.createProperty( PROPERTY.SEAS_UNIT ), self.unit)
+			valueObject.addProperty(model.createProperty( PROPERTY.UNIT ), self.unit)
 
 		# value
 		if self.hasValue():
-			valueObject.addProperty(model.createProperty( PROPERTY.SEAS_VALUE ), self.value.serialize(model))
+			valueObject.addProperty(model.createProperty( PROPERTY.RDF_VALUE ), self.value.serialize(model))
 
 		return valueObject
 	
 	
 	def parse(self, resource):
-		if not resource.isAnon():
-			valueObject = ValueObject(resource.toString())
+		from SeasObjects.rdf.Resource import Resource
+		
+		if isinstance(resource, Resource):
+			if not resource.isAnon():
+				valueObject = ValueObject(resource.toString())
+			else:
+				valueObject = ValueObject()
+			valueObject.clearTypes()
+		
+			for statement in resource.findProperties():
+				valueObject.parse(statement)
+			
+			return valueObject
+		
 		else:
-			valueObject = ValueObject()
-		valueObject.clearTypes()
-
-		for statement in resource.findProperties():
+			statement = resource
+		
 			# get predicate
 			predicate = str(statement.getPredicate())
-
+			
 			# quantity
-			if predicate == PROPERTY.SEAS_QUANTITY:
+			if predicate == PROPERTY.QUANTITYKIND:
 				try:
-					valueObject.setQuantity(statement.getResource().toString());
+					self.setQuantity(statement.getResource().toString());
 				except:
 					print "Unable to interpret seas:quantity value as resource."
 					traceback.print_exc() 
-				continue
 
 			# unit
-			if predicate == PROPERTY.SEAS_UNIT:
+			if predicate == PROPERTY.UNIT:
 				try:
-					valueObject.setUnit(statement.getResource().toString())
+					self.setUnit(statement.getResource().toString())
 				except:
 					print "Unable to interpret seas:unit value as resource."
 					traceback.print_exc() 
-				continue
 			
 			# value
-			if predicate == PROPERTY.SEAS_VALUE:
-				valueObject.setValue(Variant().parse(statement))
-				continue
+			if predicate == PROPERTY.RDF_VALUE:
+				self.setValue(Variant().parse(statement))
 
 			# pass on to Obj
-			super(ValueObject, valueObject).parse(statement)
+			super(ValueObject, self).parse(statement)
 		
-		return valueObject
 
 	def hasQuantity(self):
 		return self.quantity is not None
