@@ -6,7 +6,7 @@ class WeatherServiceProvider(ServiceProvider):
 
 	def __init__(self, uri = None):
 		ServiceProvider.__init__(self)
-		self.addType(RESOURCE.SEAS_WEATHERSERVICEPROVIDER);
+		self.addType(RESOURCE.WEATHERSERVICEPROVIDER);
 		self.setSeasIdentifierUri(uri);
 		
 
