@@ -1,5 +1,6 @@
 from SeasObjects.common.PROPERTY import PROPERTY
 from SeasObjects.model.Obj import Obj
+from SeasObjects.common.RESOURCE import RESOURCE
 
 from SeasObjects.rdf.Resource import Resource
 from SeasObjects.rdf.types import *
@@ -12,7 +13,7 @@ class Zone(Obj):
 	def __init__(self, uri = None):
 		Obj.__init__(self, uri)
 		self.zoneNUmber = None
-		self.setType(RESOURCE.SEAS_ZONE)
+		self.setType(RESOURCE.ZONE)
 
 	def hasZoneNumber(self):
 		return self.zoneNumber is not None
@@ -24,11 +25,11 @@ class Zone(Obj):
 		self.zoneNumber = zoneNumber
 
 	def serialize(self, model):
-		resource = super(Location, self).serialize(model)
+		resource = super(Zone, self).serialize(model)
 	
 		# set zone
 		if self.hasZoneNumber():
-			resource.addProperty(model.createProperty( PROPERTY.SEAS_ZONENUMBER ), self.zoneNumber)
+			resource.addProperty(model.createProperty( PROPERTY.ZONENUMBER ), self.zoneNumber)
 
 		return resource
 
@@ -52,7 +53,7 @@ class Zone(Obj):
 			predicate = str(statement.getPredicate())
 	
 			# country
-			if predicate == PROPERTY.SEAS_ZONENUMBER:
+			if predicate == PROPERTY.ZONENUMBER:
 				try:
 					self.setZoneNumber(statement.getString());
 				except:
