@@ -19,7 +19,10 @@ except:
 from SeasObjects.common.SERIALIZATION import SERIALIZATION
 from SeasObjects.common.PROPERTY import PROPERTY
 from SeasObjects.common.NS import NS
-from SeasObjects.rdf.RdfList import RdfList
+from SeasObjects.rdf.LinkedList import LinkedList
+from SeasObjects.rdf.OrderedList import OrderedList
+from SeasObjects.rdf.ItemizedList import ItemizedList
+from SeasObjects.rdf.NudeList import NudeList
 from SeasObjects.rdf.RdfLiteral import RdfLiteral
 from SeasObjects.rdf.Property import Property
 from SeasObjects.rdf.Resource import Resource
@@ -47,8 +50,17 @@ class Model(object):
     def createTypedLiteral(self, element, type):
         return self._convert_element(element, type)
     
-    def createList(self):
-        return RdfList()
+    def createOrderedList(self):
+        return OrderedList()
+    
+    def createItemizedList(self):
+        return ItemizedList()
+    
+    def createLinkedList(self):
+        return LinkedList()
+    
+    def createNudeList(self):
+        return NudeList()
     
     def _append_to_graph(self, subject, predicate, object):
         if isinstance(predicate, Property):
@@ -57,25 +69,32 @@ class Model(object):
             self.graph.add((subject, predicate, object))
     
     def _add_statement(self, statement):
-        self._append_to_graph(statement.getSubject(), statement.getPredicate(), statement.getObject())
+        if statement is not None:
+            #print "Adding statement", statement
+            self._append_to_graph(statement.getSubject(), statement.getPredicate(), statement.getObject())
         
+    # Append various types of elements to the graph. This is the main method for determining
+    # the type of a serializable object and creating the appropriate triple for it. All methods
+    # that need to make additions to the graph should use it, unless handling raw triples
+    # the the form of s-p-o of a statement that embeds them
     def _add_element(self, object, predicate, subject = None):
-        from SeasObjects.model.Variant import Variant
+        from SeasObjects.rdf.Variant import Variant
         
         if isinstance(object, Resource):
             n = object.getNode()
             
             for p in object.listProperties():
-                if isinstance(p, list):
-                    for pe in p:
-                        self._add_statement(pe)
-                        if pe.getResource() is not None:
-                            self._add_element(pe.getResource(), pe.getPredicate(), n)
-                else:
-                    self._add_statement(p)
-                    if p.getResource() is not None:
-                        self._add_element(p.getResource(), p.getPredicate(), n)
-                
+                if p is not None:
+                    if isinstance(p, list):
+                        for pe in p:
+                            self._add_statement(pe)
+                            if pe.getResource() is not None:
+                                self._add_element(pe.getResource(), pe.getPredicate(), n)
+                    else:
+                        self._add_statement(p)
+                        if p.getResource() is not None:
+                            self._add_element(p.getResource(), p.getPredicate(), n)
+                    
             for l in object.listLiterals():
                 self._add_statement(l)
             
@@ -91,9 +110,6 @@ class Model(object):
             if subject is not None and predicate is not None:
                 self._append_to_graph(subject, predicate, object.getValue())
         
-        elif isinstance(object, RdfList):
-            self._add_list(object, predicate, subject)
-            
         elif isinstance(object, Variant):
             if subject is not None and predicate is not None:
                 self._append_to_graph(subject, predicate, object.asTerm())
@@ -104,53 +120,131 @@ class Model(object):
         else:
             self._append_to_graph(subject, predicate, Literal(object))
     
+        """
+        elif isinstance(object, list):  # ordered list is the default for raw lists
+            self._add_ordered_list(object, predicate, subject)
+
+        elif isinstance(object, OrderedList):
+            self._add_ordered_list(object, predicate, subject)
+        
+        elif isinstance(object, LinkedList):
+            self._add_linked_list(object, predicate, subject)
+            
+        elif isinstance(object, ItemizedList):
+            self._add_itemized_list(object, predicate, subject)
+        """
     def _convert_element(self, element, type):
         return Literal(element, datatype = URIRef(type))
     
     def is_list(self, node):
-        first = self.graph.value(subject=node, predicate=RDF.first)
-        return first is not None
+        item = self.graph.value(subject=node, predicate=RDF.first)
+        return item is not None
+        
+    def parse_list(self, container, parent_node = None, klass = None, first = None):
+        if first is None and parent_node is not None:
+            first = self.graph.value(subject=parent_node, predicate=RDF.first)
+        if first is not None:
+            arr = self.graph.value(subject=parent_node, predicate=RDF.rest)
+            if arr:
+                return self._parse_linked_list(container, first, arr, klass)
             
-    def parse_list(self, container, node, klass = None):
+            arr = self.graph.value(subject=first, predicate=URIRef(NS.SEAS + "rawArray"))
+            if arr:
+                return self._parse_nude_list(container, first, klass)
+            
+            arr = self.graph.value(subject=first, predicate=URIRef(NS.SEAS + "array"))
+            if arr:
+                return self._parse_itemized_list(container, first, klass)
+            
+            arr = self.graph.value(subject=first, predicate=URIRef(NS.SEAS + "indexedArray"))
+            if arr:
+                return self._parse_ordered_list(container, first, klass)
+            
+        return None
+    
+
+    def _parse_list_entry(self, entry, klass = None, from_nude = False):
         from SeasObjects.model.ValueObject import ValueObject
-        from SeasObjects.model.Variant import Variant
+        from SeasObjects.rdf.Variant import Variant
         from SeasObjects.common.Tools import Tools
         
-        first = self.graph.value(subject=node, predicate=RDF.first)
-        if first:
-            if isinstance(first, Literal):
-                container.append(Variant(first.toPython()))
-            elif isinstance(first, URIRef):
-                container.append(Variant(first))
-            else:
-                if klass is None:
-                    types = []
-                    sl = self.listStatements(subject = first, predicate = URIRef(PROPERTY.RDF_TYPE), object = None)
-                    for s in sl:
-                        types.append(s.getResource().toString())
-                    klass = Tools().mapper.getClass(types, default = Variant)
+        if from_nude and klass is not None:
+            item = klass()
+            item.fromNude(entry)
+            return item
+        
+        if isinstance(entry, Literal):
+            return Variant(entry.toPython())
+        elif isinstance(entry, URIRef):
+            if entry == RDF.nil:
+                return None
+            return Variant(entry)
+        else:
+            if klass is None:
+                types = []
+                sl = self.listStatements(subject = entry, predicate = URIRef(PROPERTY.RDF_TYPE), object = None)
+                for s in sl:
+                    types.append(s.getResource().toString())
+                klass = Tools().mapper.getClass(types, default = Variant)
 
-                item = klass()
-                for s in self.find_statements_for_node(first):
-                    if s.predicate == NS.SEAS + "valueObject":
-                        itemv = ValueObject()
-                        for sv in self.find_statements_for_node(s.object):
-                            itemv.parse(sv)
-                        item.addValueObject(itemv)
-                    else:
-                        item.parse(s)
-                container.append(item)
-            rest = self.graph.value(subject=node, predicate=RDF.rest)
-            if rest:
-                self.parse_list(container, rest, klass)
+            item = klass()
+            for s in self.find_statements_for_node(entry):
+                if s.predicate == NS.SEAS + "valueObject":
+                    itemv = ValueObject()
+                    for sv in self.find_statements_for_node(s.object):
+                        itemv.parse(sv)
+                    item.addValueObject(itemv)
+                else:
+                    item.parse(s)
+            return item
+        
+    def _parse_linked_list(self, container, value, next, klass):
+        if value is not None:
+            item = self._parse_list_entry(value, klass)
+            if item: container.append(item)
+        
+        if next is not None:
+            value = self.graph.value(subject=next, predicate=RDF.first)
+            next = self.graph.value(subject=next, predicate=RDF.rest)
+            self._parse_linked_list(container, value, next, klass)
+    
+    def _parse_nude_list(self, container, current, klass):
+        arr = self.graph.value(subject=current, predicate=URIRef(NS.SEAS + "rawArray"))
+        if arr:
+            value = self.graph.value(subject=arr, predicate=RDF.value)
+            v = simplejson.loads(value.toPython())
+            for o in v:
+                container.append(self._parse_list_entry(o, klass, from_nude = True))
+    
+    def _parse_itemized_list(self, container, current, klass):
+        arr = self.graph.value(subject=current, predicate=URIRef(NS.SEAS + "array"))
+        size = self.graph.value(subject=current, predicate=URIRef(NS.SEAS + "size"))
+        if arr:
+            for s, p, o in self.graph.triples( (arr, RDF.value, None) ):
+                container.append(self._parse_list_entry(o, klass))
+    
+    def _parse_ordered_list(self, container, current, klass):
+        arr = self.graph.value(subject=current, predicate=URIRef(NS.SEAS + "indexedArray"))
+        size = self.graph.value(subject=current, predicate=URIRef(NS.SEAS + "size"))
+        if arr and size:
+            # prefill
+            for i in range(size.toPython()):
+                container.append(None)
+            #container = [None] * size.toPython()
+            for s, p, o in self.graph.triples( (arr, URIRef(NS.SEAS + "entry"), None) ):
+                index = self.graph.value(subject=o, predicate=URIRef(NS.SEAS + "index"))
+                value = self.graph.value(subject=o, predicate=RDF.value)
+                container[index.toPython()] = self._parse_list_entry(value, klass)
 
-    def _add_list(self, rdflist, predicate, subject):
+    # obsolete?
+    """
+    def _add_linked_list(self, rdflist, predicate, subject):
         from SeasObjects.model.Obj import Obj
-        from SeasObjects.model.Variant import Variant
+        from SeasObjects.rdf.Variant import Variant
 
         elements = rdflist.get_items()
-        current = list = BNode()
-        self.graph.add((subject, URIRef(predicate.id), list))
+        current = lst = BNode()
+        self.graph.add((subject, URIRef(predicate.id), lst))
         l = len(elements)
         for index, var in enumerate(elements):
             if isinstance(var, Variant):  # support lists with raw values (not just wrapped inside Evaluation
@@ -168,13 +262,14 @@ class Model(object):
             next = RDF.nil if index == l-1 else BNode()  # last item
             self.graph.add((current, RDF.rest, next))
             current = next
+    """
     
-    def add(self, element):
-        if isinstance(element, list):
-            for l in element:
+    def add(self, statement):
+        if isinstance(statement, list):
+            for l in statement:
                 self._add_element(l, None)
         else:
-            self._add_element(element, None)
+            self._add_element(statement, None)
 
     def findSubject(self, predicate, object):
         return Resource(model = self, node = self.graph.value(predicate = predicate, object=object))
